@@ -1,7 +1,19 @@
+"""
+ESPEI
+"""
+
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
+# the hackiest hack such that importing pickle will import our model that overrides the dump function
+# subclasses made later will probably be maintained.
+# we are overrideing a builtin, which is HORRIBLE
+# from espei import pickle_override
+# import sys
+# # we want to be able to get back the old pickle for dask/distributed
+# sys.modules['pickle'] = sys.modules['espei.pickle_override']
+
 import os
 import yaml
 from cerberus import Validator
