@@ -69,7 +69,7 @@ def plot_parameters(dbf, comps, phase_name, configuration, symmetry, datasets=No
     """
     em_plots = [('T', 'CPM'), ('T', 'CPM_FORM'), ('T', 'SM'), ('T', 'SM_FORM'),
                 ('T', 'HM'), ('T', 'HM_FORM')]
-    mix_plots = [('Z', 'HM_FORM'), ('Z', 'HM_MIX'), ('Z', 'SM_MIX')]
+    mix_plots = [ ('Z', 'HM_MIX'), ('Z', 'SM_MIX')]
     comps = sorted(comps)
     mod = Model(dbf, comps, phase_name)
     # This is for computing properties of formation
@@ -247,7 +247,9 @@ def dataplot(comps, phases, conds, datasets, ax=None, plot_kwargs=None, tieline_
         updated_tieline_plot_kwargs = {'linewidth':1, 'color':'k'}
         if tieline_plot_kwargs is not None:
             updated_tieline_plot_kwargs.update(tieline_plot_kwargs)
-        for eq in eq_dict.get(2,[]): # list of things in equilibrium
+        equilibria_to_plot = eq_dict.get(2, [])
+        equilibria_to_plot.extend(eq_dict.get(3, []))
+        for eq in equilibria_to_plot:
             # plot the scatter points for the right phases
             x_points, y_points = [], []
             for phase_name, comp_dict, ref_key in eq:
@@ -599,10 +601,9 @@ def _compare_data_to_parameters(dbf, comps, phase_name, desired_data, mod, confi
         response_data = response_data.flatten()
         if not bar_chart:
             extra_kwargs = {}
-            if len(response_data) < 10:
-                extra_kwargs['markersize'] = 8
-                extra_kwargs['linestyle'] = 'none'
-                extra_kwargs['clip_on'] = False
+            extra_kwargs['markersize'] = 8
+            extra_kwargs['linestyle'] = 'none'
+            extra_kwargs['clip_on'] = False
             ref = data.get('reference', '')
             mark = symbol_map[ref]['markers']
             ax.plot(indep_var_data, response_data,
